@@ -12,9 +12,6 @@ class ImageView(Widget):
         self.native = A_ImageView(self._native_activity)
         self.native.setAdjustViewBounds(True)
 
-    def set_background_color(self, value):
-        self.set_background_simple(value)
-
     def set_image(self, image):
         if image:
             self.native.setImageBitmap(image._impl.native)
@@ -26,7 +23,8 @@ class ImageView(Widget):
         # we need to convert all sizes into physical pixels.
         dpi = self.native.getContext().getResources().getDisplayMetrics().densityDpi
         # Toga needs to know how the current DPI compares to the platform default,
-        # which is 160: https://developer.android.com/training/multiscreen/screendensities
+        # which is 160:
+        #   https://developer.android.com/training/multiscreen/screendensities
         scale = float(dpi) / 160
 
         width, height, aspect_ratio = rehint_imageview(
